@@ -85,7 +85,13 @@ Ext.extend(Ext.ux.grid.MultiGrouping, Ext.util.Observable, {
             grid.on('afterrender',this.onRender,this);
             
             this.reorderer = new Ext.ux.ToolbarReorderer({
-                owner:this,
+                owner: this,
+                movedTask: new Ext.util.DelayedTask(function(){
+                    this.tbar.items.each(function(btn){
+                        btn.el.dom.style.left = '';
+                    });
+                    this.tbar.doLayout();
+                }, this),
                 createItemDD: function(button) {
                     if (button.dd != undefined) {
                         return;
@@ -173,26 +179,25 @@ Ext.extend(Ext.ux.grid.MultiGrouping, Ext.util.Observable, {
 
                             tbar_box = tbar.getEl().getBox();
                             el_y = el.getY();
-                            if (el_y<tbar_box.y | el_y>tbar_box.y + tbar_box.height){
+                            if ((el_y < tbar_box.y) || (el_y > tbar_box.y + tbar_box.height)) {
                                 this.owner.owner.deleteGroupingButton(button);
-                            }
-                            else{
-                            
-                            el.moveTo(me.buttonXCache[button.id], el.getY(), {
-                                duration: me.animationDuration,
-                                scope   : this,
-                                callback: function() {
-                                    button.resumeEvents();
-                                    if (button.menu) {
-                                        button.menu.un('beforeshow', menuDisabler, me);
+                            } else {
+                                el.moveTo(me.buttonXCache[button.id], el.getY(), {
+                                    duration: me.animationDuration,
+                                    scope   : this,
+                                    callback: function() {
+                                        me.movedTask.delay(200);
+                                        button.resumeEvents();
+                                        if (button.menu) {
+                                            button.menu.un('beforeshow', menuDisabler, me);
+                                        }
+
+                                        tbar.fireEvent('reordered', button, tbar);
                                     }
-                                    
-                                    tbar.fireEvent('reordered', button, tbar);
-                                }
-                            });
+                                });
                             
-                            el.setStyle('zIndex', this.startZIndex);
-                        }
+                                el.setStyle('zIndex', this.startZIndex);
+                            }
                         }
                     });
                 },
@@ -200,12 +205,12 @@ Ext.extend(Ext.ux.grid.MultiGrouping, Ext.util.Observable, {
                 onMovedLeft: function(item, newIndex, oldIndex) {
                     var tbar  = this.target,
                         items = tbar.items.items;
-                    
+
+                    this.movedTask.cancel();
                     if (newIndex != undefined && newIndex != oldIndex) {
                         //move the button currently under drag to its new location
                         tbar.remove(item, false);
                         tbar.insert(newIndex, item);
-                        
                         //set the correct x location of each item in the toolbar
                         this.updateButtonXCache();
                         for (var index = 0; index < items.length; index++) {
@@ -327,6 +332,12 @@ Ext.extend(Ext.ux.grid.MultiGrouping, Ext.util.Observable, {
 	            });	
             }
             this.expandedItems = [];
+
+            this.grid.on('resize', function(grid, width, height, e){
+                // после изменения порядка группировки при изменении размеров
+                // окошка происходил наезд кнопок группировки друг на друга
+                grid.groupPlugin.resetLayout(grid.grouper.tbar);
+            });
         }
 	},
 	/**
@@ -410,7 +421,10 @@ Ext.extend(Ext.ux.grid.MultiGrouping, Ext.util.Observable, {
         // При явном вызове destroy event'ы не отсылаются. Удалим dragSource вручную.
         button.dd.destroy();
         button.destroy();
-        this.doGroup(this.getGroupColumns())
+        this.doGroup(this.getGroupColumns());
+        // надо подождать прогрузку, прежде чем обрабатывать атрибут left
+        var el = this;
+        setTimeout(function () {el.resetLayout(el.tbar)}, 500);
     },
     /**
      * Событие отрисовки панели группировки
@@ -528,6 +542,7 @@ Ext.extend(Ext.ux.grid.MultiGrouping, Ext.util.Observable, {
 				}
 	        }
 		}
+		this.resetLayout(this.tbar);
 	},
 	/**
 	 * Перед загрузкой выставим параметры загрузки
@@ -718,6 +733,20 @@ Ext.extend(Ext.ux.grid.MultiGrouping, Ext.util.Observable, {
             this.grid.getSelectionModel().selectRow(this.grid.store.totalLength-1);
     		e.stopEvent();
     		}
+    },
+    /**
+	 * после различных событий происходил наезд кнопок группировки
+     * друг на друга, так как не очищался css-атрибут left
+	 * @param {Ext.Toolbar} tbar Параметры события нажатия клавиши
+	 */
+    resetLayout: function(tbar) {
+        if (tbar) {
+            var items = tbar.items.items;
+            for (var i = 0; i < items.length; i++)
+                if (items[i].el)
+                    items[i].el.setStyle('left', 'auto');
+            tbar.layout.container.doLayout();
+        }
     }
 });
 
@@ -1419,6 +1448,7 @@ Ext.m3.MultiGroupingGridPanel = Ext.extend(Ext.ux.grid.livegrid.GridPanel, {
     }
 });
 
+Ext.reg('multigroupinggridpanel', Ext.m3.MultiGroupingGridPanel);
 
 /*******************
  * Плагин для экпорта в xls - отправляет на сервер запрос с нужными параметрами
