@@ -131,28 +131,39 @@ Ext.app.form.SearchField = Ext.extend(Ext.form.TwinTriggerField, {
     }
 
     ,onTrigger2Click : function(e, html, arg){
-        var value = this.getRawValue();
-        var cmp = this.getComponentForSearch();
+        var value = this.getRawValue(),
+            cmp = this.getComponentForSearch(),
+            search = this,
+            o,
+            store,
+            loader,
+            rootNode;
+        this.setDisabled(true);
+        this.setHideTrigger(true);
         if (cmp instanceof Ext.grid.GridPanel) {
-            var o = {start: 0};
-            var store = cmp.getStore();
-	        store.baseParams = store.baseParams || {};
-	        store.baseParams[this.paramName] = value;
-	        store.baseParams[this.paramId] = this.nodeId || '';	
-	        store.reload({params:o});
+            o = {start: 0};
+            store = cmp.getStore();
+            store.baseParams = store.baseParams || {};
+            store.baseParams[this.paramName] = value;
+            store.baseParams[this.paramId] = this.nodeId || '';	
+            store.reload({params:o});
         } else if (cmp instanceof Ext.ux.tree.TreeGrid) {
-        	var loader = cmp.getLoader();
-        	loader.baseParams = loader.baseParams || {};
-	        loader.baseParams[this.paramName] = value;
-        	var rootNode = cmp.getRootNode();
-        	loader.load(rootNode);
-        	rootNode.expand();
-        	//console.log(rootNode);
+            loader = cmp.getLoader();
+            loader.baseParams = loader.baseParams || {};
+            loader.baseParams[this.paramName] = value;
+            rootNode = cmp.getRootNode();
+            loader.load(rootNode);
+            rootNode.expand();
+            // console.log(rootNode);
         };
         if (value) {
-        	this.hasSearch = true;
-	    	this.triggers[0].show();
+            this.hasSearch = true;
+            this.triggers[0].show();
         }
+        setTimeout(function(){
+            search.setDisabled(false);
+            search.setHideTrigger(false);
+        }, 200);
     }
     
     ,clear : function(node_id){ this.onTrigger1Click() }
