@@ -1,15 +1,17 @@
-#coding: utf-8
+# coding: utf-8
 """
 Модуль с преднастроенными панелями-деевьями
-
-Created on 25.06.2010
-
-@author: prefer
 """
+from __future__ import absolute_import
 
-from m3_ext.ui import containers, controls, menus, render_component
 from m3.actions.urls import get_url
 
+from m3_ext.ui import containers
+from m3_ext.ui import controls
+from m3_ext.ui import menus
+from m3_ext.ui import render_component
+from m3_ext.ui.fields import ExtSearchField
+
 
 class ExtObjectTree(containers.ExtTree):
     """
@@ -135,12 +137,27 @@ class ExtObjectTree(containers.ExtTree):
         # иначе, сортируются как элементы
         self.folder_sort = True
 
+        # Возможность сортировки в дереве
+        self.enable_tree_sort = True
+
         # После редактирования и добавления обновляется только тот узел дерева,
         # в котором произошли изменения
         self.incremental_update = False
 
+        # Список исключений для make_read_only
+        self._mro_exclude_list = []
+
         self.init_component()
 
+    def add_search_field(self):
+        u"""Добавляет строку поиска в гриде."""
+        self.top_bar.search_field = ExtSearchField(
+            empty_text=u'Поиск', width=200, component_for_search=self)
+        self.top_bar.add_fill()
+        self.top_bar.items.append(self.top_bar.search_field)
+
+        self._mro_exclude_list.append(self.top_bar.search_field)
+
     def render(self):
         """
         Переопределяем рендер дерева для того,
@@ -216,6 +233,7 @@ class ExtObjectTree(containers.ExtTree):
         self._put_params_value('rowIdName', self.row_id_name)
         self._put_params_value('parentIdName', self.parent_id_name)
         self._put_params_value('folderSort', self.folder_sort)
+        self._put_params_value('enableTreeSort', self.enable_tree_sort)
         self._put_params_value('incrementalUpdate', self.incremental_update)
 
     def t_render_base_config(self):
